@@ -18,7 +18,7 @@ c
 
       ijudg = 1  ! = mstz( 56 )      
       imadj = 1
-      icrhi  = 1 ! =  mstz( 54  )  nasa xsection
+      icrhi  = 0 ! =  mstz( 54  ) (1--> nasa xsection; 0-->Shen's Xs)
       iqmax = 150
       bplus = 0.  ! parz(168)
 
