@@ -1,3 +1,9 @@
+!   make next deinfed if first interaction iformation of nuclius break up
+!   information is needed (make firstcollison=0 in epiev in ephook.f )
+!
+#define BREAKUPINFO
+#undef BREAKUPINFO
+
 #undef  DUMMYDATE
 #if defined (NEXT486) || defined (KEKB)
 #define DUMMYDATE
@@ -66,6 +72,15 @@ c/////////
       logical first
       data first /.true./
       save 
+
+#if defined (BREAKUPINFO)
+c            use this when you want to get heavy ion breakup info.
+c            at the first collision. (also put it in ephook --> epiev
+c            to make firstcollision=0
+      integer firstcollision
+      common /checkglaub/  firstcollision
+#endif
+c///////////////
 c////////////
 c      logical deb
 c      common /cdebug/ deb
@@ -81,6 +96,7 @@ c     *   1, 1, ia, iz,  1, ELAB, KKMAT, icon)
       endif
 
       KKMAT = -1
+c      KKMAT = 1
       NEVENT = NEVENT + 1 
 
       cdiff = cdiff0  ! 3% relative error in Econsv. ok
@@ -92,7 +108,6 @@ c     *   1, 1, ia, iz,  1, ELAB, KKMAT, icon)
          ELAB = ELAB/pj.subcode
       endif
       call ccos2dpjidp( pj, IDP, NPMASS, NPCHAR )
-
       dodpm = .false.
       if( IDP .eq. 0) then
 c            dpm cannot treat this         
@@ -154,6 +169,7 @@ c                 dpm; GeV/n
 c&&&&&
 c            call rnd1s(irsave)
 c &&&&&
+
                   call DT_KKINC(
      *              NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,ELAB,KKMAT,icon)
                   if(icon .ne. 0) then
@@ -165,7 +181,7 @@ c                   so we change the energy by 1 %
 c                  if(loopc .gt. 100) then    ! probably useless.
                      if(loopc .gt.  20) then
                         write(ErrorOut,*)
-     *                    ' proj code, subcode, charge=',pj.code,
+     *                    ' pj code, subcode, charge=',pj.code,
      *                    pj.subcode, pj.charge, ' E=',pj.fm.p(4),
      *                    ' Target A=', ia, ' Z=', iz,
      *                    ' loopc=',loopc
@@ -185,16 +201,17 @@ c                            no ptcl produced
                   Ein = NTMASS*masp + pj.fm.p(4)
                   dErel = sumTE/Ein -1.
 c////////////////
-c                  write(*,'(a,1p7g13.4, i3)') 'dE ', 
-c     *            Ein, pj.fm.p(4)-pj.mass, dErel,
-c     *            sumTE, sumKE, sumRareTE, sumRareKE, krarec
-c/////////////
+c                  if(firstcollision==0)then
+c                     write(0,*) 
+c     *                    ' dErel=',dErel, ' sumTE=',sumTE, ' Ein=',Ein
+c                  endif
+c////////////
                   if( abs(dErel) .lt. abs(diffmin)) then
                      diffmin = dErel
                   endif
 
                   if(abs(dErel) .gt. cdiff) then
-c                     econ !=0 --> Energy consv. broken
+c  
                      econloopc = econloopc +1
                      if(econloopc .gt. 10 
      *                  .and. cdiff .ne. cdiff0 ) then
@@ -355,9 +372,22 @@ c
 
       integer i
       integer code, subcode, charge
-
-
-c///////////////
+#if defined (BREAKUPINFO)
+      integer firstcollision
+      common /checkglaub/  firstcollision
+      character(2):: id
+!            counters
+      integer ngNc   !  generated nucleons
+      integer neNPc  !  evaporated nucleons from projectile 
+      integer neNTc  !  evaporated nucleons from target
+      integer neHPc   ! evaporated heavies from projectile 
+      integer neHTc   ! evaporated heavyies from target 
+      integer nrPc   ! remnant  heavies from projectile
+      integer nrTc   ! remnant  heavies from target 
+      real(8):: pjKEn  ! projecitle kinetic energy /n
+      real(8):: thresh   ! pjKEn*0.5. if KE/n of evaporation > this
+                   ! it should be from projectile 
+#endif
 c      if(NHKK .gt. 1000 ) then
 c         write(0,*) ' NHKK=',NHKK
 c      endif
@@ -368,15 +398,63 @@ c///////////////
       krarec = 0
       sumRareTE =0.
       sumRareKE = 0.
-
+#if defined (BREAKUPINFO)
+      ngNc = 0
+      neNPc = 0
+      neNTc = 0 !  evaporated nucleons from target
+      neHPc = 0  ! evaporated heavies from projectile 
+      neHTc  = 0  ! evaporated heavyies from target 
+      nrPc  = 0  ! remnant  heavies from projectile
+      nrTc  = 0 ! remnant  heavies from target 
+      pjKEn = pj.fm.p(4) + pj.mass
+      if(pj.code == kgnuc ) then
+         pjKEn = pjKEn/pj.subcode
+      endif
+      thresh = pjKEn*0.5
+#endif
       do i=1, NHKK
          IF (ABS(ISTHKK(i)).EQ.1) THEN
-            if(IDHKK(i) .lt. 79000.) then
+            if(IDHKK(i) .lt. 79000) then
                call ckf2cos(IDHKK(i), code, subcode, charge)
+#if defined (BREAKUPINFO)
+               if( firstcollision == 0 ) then
+                  if( code == knuc ) then
+                     if(ISTHKK(i) > 0 ) then
+                        id = 'G'
+                        ngNc = ngNc + 1
+                     else
+                        if(( PHKK(4,i) - PHKK(5,i)) >   thresh) then
+                           neNPc = neNPc + 1
+                           id = 'PE'
+                        else
+                           id = 'TE'
+                           neNTc = neNTc + 1
+                        endif
+                     endif
+                     write(*,'(a,3i4, a, 1p, g14.4,i3)')
+     *                  id, code, subcode, charge,
+     *                 ' KE/n =', PHKK(4,i) - PHKK(5,i),ISTHKK(i)
+                  endif
+               endif
+#endif
             else
                charge = IDXRES(i)
                code = kgnuc
                subcode = IDRES(i)
+#if defined (BREAKUPINFO)
+               if(firstcollision == 0 ) then
+                  if( (PHKK(4,i) - PHKK(5,i))/subcode > thresh) then
+                     neHPc =  neHPc + 1
+                     id = "PE"
+                  else
+                     neHTc =  neHTc + 1
+                     id = "TE"
+                  endif
+                  write(*,'(a,3i4, a, 1p, g14.4,i6)')
+     *            id, code, subcode, charge,
+     *            ' KE/n =', (PHKK(4,i) - PHKK(5,i))/subcode, ISTHKK(i)
+               endif
+#endif
             endif
             sumKE = sumKE + (PHKK(4,i) - PHKK(5,i))
             sumTE = sumTE + PHKK(4,i)
@@ -387,6 +465,9 @@ c///////////////
                a(ntp).fm.p(2) = PHKK(2,i)
                a(ntp).fm.p(3) = PHKK(3,i)
                a(ntp).fm.p(4) = PHKK(4,i)
+               if( code == kgnuc)  then
+                  a(ntp).mass =  PHKK(5,i)
+               endif
             else
                krarec = krarec + 1 
                sumRareKE = sumRareKE +  (PHKK(4,i) - PHKK(5,i))
@@ -403,21 +484,39 @@ c             residual nucleus;
             subcode = IDRES(i)
             ntp = ntp +1
             call cmkptc(code, subcode, charge, a(ntp))
+            a(ntp).mass =  PHKK(5,i)
             a(ntp).fm.p(1) = PHKK(1,i)
             a(ntp).fm.p(2) = PHKK(2,i)
             a(ntp).fm.p(3) = PHKK(3,i)
             a(ntp).fm.p(4) = PHKK(4,i)
             sumKE = sumKE + (PHKK(4,i) - PHKK(5,i))
             sumTE = sumTE + PHKK(4,i)
-c////////////////
-c            write(0,*) ' residual A,Z=',subcode,charge
+#if defined (BREAKUPINFO)
+            if( firstcollision == 0 ) then
+               if((PHKK(4,i) - PHKK(5,i))/subcode > thresh) then
+                  nrPc = nrPc + 1
+                  id = "PR"
+               else
+                  nrTc = nrTc + 1
+                  id = "TR"
+               endif
+               write(*,'(a,3i4, a, 1p, g14.4,i6)')
+     *          id, code, subcode,charge,
+     *          ' KE/n=', (PHKK(4,i) - PHKK(5,i))/subcode, ISTHKK(i)
+            endif
 c            write(0,*) ' p=',PHKK(1,i), PHKK(2,i), PHKK(3,i),PHKK(4,i)
-c/////////////
+#endif
          ENDIF
       enddo
 c     -------------- rotate
       call crot3mom(pj, a, ntp)
-
+#if defined (BREAKUPINFO)
+      firstcollision = 1
+      id = "No"
+      write(*,'(a)') '   ntp  ngNc  neNPc neNTc neHPc neHTc  nrPc  nrTc'
+      write(*, '(a,8i6)') id,
+     *  ntp, ngNc, neNPc, neNTc, neHPc, neHTc, nrPc, nrTc
+#endif
       end
       subroutine cdpmNoPtcl
 c         clear no. of produced partilce
@@ -433,6 +532,7 @@ c         clear no. of produced partilce
       NHKK= 0
       end
 
+
       SUBROUTINE DT_USRHIS(MODE)
       implicit none
       integer MODE
@@ -548,9 +648,67 @@ c/////////////////
 c          init dpm; Thru this call, input data is read via TempDev
 c     Glauber initialization data location is given in that
 c     data and the call to cdpmOpen is made from within dpmjet
-
+      IEMU = 0
       CALL DT_DTUINI(NEVTS,EPN,NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,IEMU)
 
       close(TempDev)
 
       end
+      subroutine cdpmOpen(io, file)
+      implicit none
+c      since dpmjet cannot use long file name, we may encounter
+c      difficulty in dealing with full path which is needed to
+c      specify the files when distributing jobs over a 
+c      number of  workstations.  So I had to make a
+c      correction in the dpmjet program;Say, the open statements
+c      for reading GLAUB-PAR data
+
+c         OPEN(LLOOK,FILE=CGLB//'.GLB',STATUS='UNKNOWN')
+c         OPEN(LLOOK,FILE=CGLB(1:I-1)//'.GLB',STATUS='UNKNOWN')
+c
+c      are replaced  by 
+c      
+c           call cdpmOpen(LLOOK, CFILE)
+      
+      integer io  ! input.  file descripter to be opened
+      character*12 file  ! input. file name, say, containig glauber
+                   !  calculation result, such as atmos.GLB. 
+                   ! the full path is assmued to be TopDir/file
+
+
+      character*100 path
+
+
+      integer icon
+      call cformFullPath(file, path)
+
+      call copenf(io, path, icon)
+      if(icon .ne. 0) then
+         call cerrorMsg(path, 1)
+         call cerrorMsg('above file cannot be opened', 0)
+      endif
+      end
+
+
+      subroutine cdpmOpen2(io, file)
+      implicit none
+#include "Zmanager.h"
+c      This opens a file with Cosmos/Data/DPM as a prefix
+c    
+      integer io  ! input.  file descripter to be opened
+      character*(*) file  ! input. file name.
+
+      character*100 path
+      integer icon, klena
+
+      path = ' '
+      path = TopDir(1:TopDirLeng)//'/Data/DPM/'
+     *       //file(1:klena(file))
+
+      call copenf(io, path, icon)
+
+      if(icon .ne. 0) then
+         call cerrorMsg(path, 1)
+         call cerrorMsg('above file cannot be opened', 0)
+      endif
+      end
