@@ -199,61 +199,3 @@ c             and set it in TopDir in Zmanager.h
       endif
 
       end
-      subroutine cdpmOpen(io, file)
-      implicit none
-c      since dpmjet cannot use long file name, we may encounter
-c      difficulty in dealing with full path which is needed to
-c      specify the files when distributing jobs over a 
-c      number of  workstations.  So I had to make a
-c      correction in the dpmjet program;Say, the open statements
-c      for reading GLAUB-PAR data
-
-c         OPEN(LLOOK,FILE=CGLB//'.GLB',STATUS='UNKNOWN')
-c         OPEN(LLOOK,FILE=CGLB(1:I-1)//'.GLB',STATUS='UNKNOWN')
-c
-c      are replaced  by 
-c      
-c           call cdpmOpen(LLOOK, CFILE)
-      
-      integer io  ! input.  file descripter to be opened
-      character*12 file  ! input. file name, say, containig glauber
-                   !  calculation result, such as atmos.GLB. 
-                   ! the full path is assmued to be TopDir/file
-
-
-      character*100 path
-
-
-      integer icon
-      call cformFullPath(file, path)
-
-      call copenf(io, path, icon)
-      if(icon .ne. 0) then
-         call cerrorMsg(path, 1)
-         call cerrorMsg('above file cannot be opened', 0)
-      endif
-      end
-
-
-      subroutine cdpmOpen2(io, file)
-      implicit none
-#include "Zmanager.h"
-c      This opens a file with Cosmos/Data/DPM as a prefix
-c    
-      integer io  ! input.  file descripter to be opened
-      character*(*) file  ! input. file name.
-
-      character*100 path
-      integer icon, klena
-
-      path = ' '
-      path = TopDir(1:TopDirLeng)//'/Data/DPM/'
-     *       //file(1:klena(file))
-
-      call copenf(io, path, icon)
-
-      if(icon .ne. 0) then
-         call cerrorMsg(path, 1)
-         call cerrorMsg('above file cannot be opened', 0)
-      endif
-      end
