@@ -22,7 +22,9 @@ c                           3 ==> reached at inner boundery.
       record /track/ aTrack
 
 c      record /track/ inci
-c      record /coord/ angle
+c////////////
+      record /coord/ pdir, cdir
+c////////////
       record /coord/ tetafai
       
       character*128 input
@@ -134,7 +136,8 @@ c     *
       write(0,'("i ",  i6,  i4, g13.4,3f11.7,f7.1)')
      *   EventNo, inci.p.code,
      *   inci.p.fm.e,  -angle.r(1),  -angle.r(2), -angle.r(3)
-c         
+       write(0,'(a, 1p, 6g15.5)')
+     *    '### ', DetXaxis.r(1:3), DetZaxis.r(1:3)
       do i = 1, NoOfSites
          SumEloss(i) = 0.
          do j = 1, 4
@@ -235,9 +238,6 @@ c
 c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
-c     **************************
-
-
       obstimes = obstimes + 1.d0
       if(mod(obstimes, 100000.d0) .eq. 0. ) then 
          dosort=.false.
@@ -378,7 +378,6 @@ c///////////////
      *   ' generation phase finished. now writing data'
 
       call cgetfname(basefilename, basefilename2)
-
       call cqFirstID(firstcdepth)
       firstcdepth = firstcdepth* 0.1     ! in g/cm2  First col depth.
 
@@ -429,6 +428,7 @@ c              to deep penetration
 
          filename = basefilename2(1:klena(basefilename2))//".hyb"
          call copenfw2(fnoB, filename, 1, icon)
+
          write(fnoB,
      *   '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, 1pE11.3, 0p,
      *     2f7.0,i2,a )')
@@ -449,6 +449,7 @@ c              to deep penetration
          sumUncertain = 0.
          sumEcrash = 0.
          sumEspace = 0.
+
          do i = 1, NoOfASSites 
             if(Eabsorb(1) .ne. 0) then
                write(fnoB, '("t ", i3, 2f7.1,  2f6.3,
